@@ -17,7 +17,6 @@
 # under the License.
 from __future__ import annotations
 
-import warnings
 from base64 import b64encode
 from functools import cached_property
 from typing import TYPE_CHECKING, Container, Sequence
@@ -149,16 +148,16 @@ class SSHOperator(BaseOperator):
 
     def get_ssh_client(self) -> SSHClient:
         # Remember to use context manager or call .close() on this when done
-        self.log.info("Creating ssh_client")
         return self.hook.get_conn()
 
-    def exec_ssh_client_command(self, ssh_client: SSHClient, command: str) -> tuple[int, bytes, bytes]:
-        warnings.warn(
+    @deprecated(
+        reason=(
             "exec_ssh_client_command method on SSHOperator is deprecated, call "
-            "`ssh_hook.exec_ssh_client_command` instead",
-            AirflowProviderDeprecationWarning,
-            stacklevel=2,
-        )
+            "`ssh_hook.exec_ssh_client_command` instead"
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
+    def exec_ssh_client_command(self, ssh_client: SSHClient, command: str) -> tuple[int, bytes, bytes]:
         return self.hook.exec_ssh_client_command(
             ssh_client, command, timeout=self.cmd_timeout, environment=self.environment, get_pty=self.get_pty
         )
@@ -192,9 +191,19 @@ class SSHOperator(BaseOperator):
         enable_pickling = conf.getboolean("core", "enable_xcom_pickling")
         if not enable_pickling:
             result = b64encode(result).decode("utf-8")
+
         return result
 
     def tunnel(self) -> None:
         """Get ssh tunnel."""
         ssh_client = self.hook.get_conn()  # type: ignore[union-attr]
         ssh_client.get_transport()
+
+    def on_kill(self) -> None:
+        """Close the ssh client session."""
+        ssh_client = self.hook.client
+        if ssh_client:
+            ssh_client.close()
+            self.log.info("SSH client closed.")
+        else:
+            self.log.info("No SSH client to close.")
